@@ -3,10 +3,10 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.0902';
+our $VERSION = '0.1000';
 
 use Carp;
-use List::MoreUtils 'first_index';
+use List::MoreUtils qw/ any first_index /;
 use Moo;
 use Music::Scales;
 
@@ -16,18 +16,21 @@ use namespace::clean;
 
 has scale_note => (
     is      => 'ro',
+    isa     => sub { die 'Invalid note' unless _valid_note( $_[0] ) },
     default => sub { 'C' },
 );
 
 
 has scale_name => (
     is      => 'ro',
+    isa     => sub { die 'Invalid scale' unless _valid_scale( $_[0] ) },
     default => sub { 'major' },
 );
 
 
 has chords => (
     is      => 'ro',
+    isa     => sub { die 'Invalid boolean' unless $_[0] == 0 || $_[0] == 1 },
     default => sub { 1 },
 );
 
@@ -35,6 +38,9 @@ has chords => (
 sub parse {
     my ( $self, $chord ) = @_;
 
+    die 'No chord to parse'
+        unless $chord;
+
     # Literal diatonic modes when chords attribute is zero
     my @roman = qw( I ii iii IV V vi vii ); # Default to major/ionian
     if ( $self->scale_name eq 'dorian' ) {
@@ -140,6 +146,38 @@ sub _pos_acc {
     return $position, $accidental;
 }
 
+sub _valid_note {
+    my ($note) = @_;
+
+    my @valid = ();
+
+    my @notes = 'A' .. 'G';
+
+    push @valid, @notes;
+    push @valid, map { $_ . '#' } @notes;
+    push @valid, map { $_ . 'b' } @notes;
+
+    return any { $_ eq $note } @valid;
+}
+
+sub _valid_scale {
+    my ($name) = @_;
+
+    my @valid = qw(
+        ionian
+        major
+        dorian
+        phrygian
+        lydian
+        mixolydian
+        aeolian
+        minor
+        locrian
+    );
+
+    return any { $_ eq $name } @valid;
+}
+
 1;
 
 __END__
@@ -154,7 +192,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.0902
+version 0.1000
 
 =head1 SYNOPSIS
 
@@ -209,13 +247,13 @@ mode B<scale_name>.
 
 =head2 scale_note
 
-Note on which the scale is based.
-
-Default: C<C>
+Note on which the scale is based.  Default: C<C>
 
 =head2 scale_name
 
-Name of the scale.  The diatonic mode names supported are:
+Name of the scale.  Default: C<major>
+
+The diatonic mode names supported are:
 
   ionian / major
   dorian
@@ -225,8 +263,6 @@ Name of the scale.  The diatonic mode names supported are:
   aeolian / minor
   locrian
 
-Default: C<major>
-
 =head2 chords
 
 Are we given chords to B<parse> with major (C<M>) and minor (C<m>)
@@ -254,19 +290,22 @@ Create a new C<Music::ToRoman> object.
 
 Parse a note or chord name into a Roman numeral representation.
 
-For instance, the Roman numeral representation for the C<aeolian> (or minor)
-mode is: C<i ii III iv v VI VII> - where the case indicates the major/minor
-status of the given chord.
+For instance, the Roman numeral representation for the C<aeolian> (or
+minor) mode is: C<i ii III iv v VI VII> - where the case indicates the
+major/minor status of the given chord.
 
-This can be overridden by parsing say, C<BM7> (B dominant seventh), thus
-producing C<II7> in the key of A minor.
+This can be overridden by parsing say, C<BM7> (B dominant seventh),
+thus producing C<II7>.
 
-If a major/minor chord designation is not provided, C<M> major is assumed.
+If a major/minor chord designation is not provided, C<M> major is
+assumed.
 
-If the B<chords> attribute is off and a single note is given, the diatonic mode
-of the B<scale_name> is used to find the correct Roman numeral representation.
+If the B<chords> attribute is off and a single note is given, the
+diatonic mode of the B<scale_name> is used to find the correct Roman
+numeral representation.
 
-A diminished chord may be given as C<dim>, which is then converted to C<o>.
+A diminished chord may be given as either C<o> or C<dim>, and both are
+rendered as C<o>.
 
 =head1 SEE ALSO
 
@@ -278,8 +317,8 @@ L<Music::Scales>
 
 L<https://en.wikipedia.org/wiki/Roman_numeral_analysis>
 
-For example usage, check out the files F<eg/roman> and F<eg/basslines> in
-L<Music::BachChoralHarmony>.
+For example usage, check out the files F<eg/roman> and F<eg/basslines>
+in L<Music::BachChoralHarmony>.
 
 =head1 AUTHOR
 
